# witness

A minimal ETL library.
Intended to be simple and concise.

## Installation
```
python3 -m pip install witness-etl
```

## Versioning
This lib supports [SemVer](https://semver.org/) approach for all packages released.

## Contributing
Want to help or got questions? 
[Contact me.](mailto:evgeniypalych@gmail.com)
